@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
 our $DATE = '2015-02-24'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -107,13 +107,14 @@ _
             summary => 'Perl version to use (overrides scan_prereqs/dist.ini)',
         },
         lite => {
-            schema => ['bool*', is=>1],
+            schema => ['bool*'],
             default => 1,
             summary => 'Use Perl::PrereqScanner::Lite instead of Perl::PrereqScanner',
+            "summary.alt.bool.not" =>
+                'Use Perl::PrereqScanner instead of Perl::PrereqScanner::Lite',
             description => <<'_',
 
-Lite is faster but it still misses detecting some modules, so it's not the
-default.
+Lite is faster but it might still miss detecting some modules.
 
 _
         },
@@ -317,7 +318,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.22 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-02-24.
+This document describes version 0.23 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-02-24.
 
 =head1 SYNOPSIS
 
@@ -328,9 +329,8 @@ This document describes version 0.22 of App::LintPrereqs (from Perl distribution
 
 =head2 lint_prereqs(%args) -> [status, msg, result, meta]
 
-{en_US Check extraneous/missing prerequisites in dist.ini}.
+Check extraneous/missing prerequisites in dist.ini.
 
-{en_US 
 Check C<[Prereqs / *]> (as well as C<OSPrereqs>, C<Extras/lint-prereqs/Assume-*>)
 sections in your C<dist.ini> against what's actually being used in your Perl code
 (using C<Perl::PrereqScanner::Lite>) and what's in Perl core list of modules.
@@ -356,24 +356,19 @@ ignore them:
  [Extras / lint-prereqs / assume-provided]
  Qux::Quux=0
 
-}
-
 Arguments ('*' denotes required arguments):
 
 =over 4
 
 =item * B<lite> => I<bool> (default: 1)
 
-{en_US Use Perl::PrereqScanner::Lite instead of Perl::PrereqScanner}.
+Use Perl::PrereqScanner::Lite instead of Perl::PrereqScanner.
 
-{en_US 
-Lite is faster but it still misses detecting some modules, so it's not the
-default.
-}
+Lite is faster but it might still miss detecting some modules.
 
 =item * B<perl_version> => I<str>
 
-{en_US Perl version to use (overrides scan_prereqs/dist.ini)}.
+Perl version to use (overrides scan_prereqs/dist.ini).
 
 =back
 
